#[non_exhaustive]pub enum RlpDeriveError {
Decode(DecodeError),
Field,
WrongFieldCount {
expected: usize,
found: usize,
},
}Expand description
Error used by derive-generated RLP struct encoders and decoders.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Decode(DecodeError)
The bounded codec rejected the input or output buffer.
Field
A field-specific codec rejected one generated field operation.
WrongFieldCount
The decoded list field count did not match the generated struct shape.