DecodeError

Enum DecodeError 

#[non_exhaustive]
pub enum DecodeError {
Show 14 variants InputTooLarge, TrailingBytes, DecoderOverread, Malformed, UnexpectedList, UnexpectedScalar, ListTooLong, NestingTooDeep, AllocationExceeded, ProofTooLarge, ItemCountExceeded, UnreviewedDeploymentPolicy, LengthOverflow, OffsetOutOfBounds,
}
Shared decode failure categories.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


InputTooLarge

The byte input is larger than the active decode budget.



TrailingBytes

The input contains trailing bytes after a decoded value.



DecoderOverread

A decoder reported consuming more bytes than the input contains.



Malformed

The input is malformed for the selected wire format.



UnexpectedList

An RLP list was encountered where a scalar byte string was required.



UnexpectedScalar

An RLP scalar was encountered where a list was required.



ListTooLong

A decoded list contains more items than the active list budget.



NestingTooDeep

Decoding exceeded the active nesting-depth budget.



AllocationExceeded

A decoder requested allocation beyond the active allocation budget.



ProofTooLarge

A proof contains more nodes than the active proof-node budget.



ItemCountExceeded

A decoder visited more items than the active cumulative item budget.



UnreviewedDeploymentPolicy

A deployment used an unchanged starter budget policy.



LengthOverflow

Length or offset arithmetic overflowed.



OffsetOutOfBounds

An offset or range points outside the input.

Implementations

Source

impl DecodeError

pub const fn code(self) -> &'static str

Stable machine-readable error code.

pub const fn message(self) -> &'static str

Stable human-readable error message.

pub const fn category(self) -> DecodeErrorCategory

Stable high-level category for policy decisions.

pub const fn resource(self) -> Option<ResourceError>

Returns the resource budget that was exceeded, if this is a resource exhaustion error.