pub enum DecodeError {
InputTooLarge,
TrailingBytes,
DecoderOverread,
Malformed,
ListTooLong,
NestingTooDeep,
AllocationExceeded,
}Expand description
Shared decode failure categories.
Variants
InputTooLarge
The byte input is larger than the active decode budget.
TrailingBytes
The input contains trailing bytes after a decoded value.
DecoderOverread
A decoder reported consuming more bytes than the input contains.
Malformed
The input is malformed for the selected wire format.
ListTooLong
A decoded list contains more items than the active decode budget.
NestingTooDeep
Decoding exceeded the active nesting-depth budget.
AllocationExceeded
A decoder requested allocation beyond the active allocation budget.
Implementations
Sourceimpl DecodeError
impl DecodeError
Sourcepub const fn category(self) -> DecodeErrorCategory
pub const fn category(self) -> DecodeErrorCategory
Stable high-level category for policy decisions.
Sourcepub const fn resource(self) -> Option<ResourceError>
pub const fn resource(self) -> Option<ResourceError>
Returns the resource budget that was exceeded, if this is a resource exhaustion error.